from to_sentry.config_parser import ToSentryConfigParser

import raven
import raven.events
import urllib2
import warnings

def usage():
    print "Usage: to_sentry <sentry feed> Subject line ... " 

def send(argv, stdin, client_factory=raven.Client):
    if len(argv) < 2:
        usage()
        return 1
    with warnings.catch_warnings():
        warnings.simplefilter("ignore")
        client = client_factory(dsn=ToSentryConfigParser()[argv[1]])
        data = stdin.read()
        if data:
            client.capture('Message', 
                           message=' '.join(argv[2:]),
                           data = None,
                           extra = {'stdin':data})



#!/usr/bin/env python
"""
to_sentry
======

Command line tool to dump data to sentry.  

"""

from setuptools import setup


setup(
    name='to_sentry',
    version='0.0.2',
    author='Adam DePrince',
    author_email='adeprince@nypublicradio.org',
    description='Simple command line driven logging for sentry.',
    long_description=__doc__,
    py_modules = [
        "to_sentry/config_parser",
        "to_sentry/transmitter",
        ],
    packages = ["to_sentry"],
    zip_safe=True,
    license='BSD',
    include_package_data=True,
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Operating System :: OS Independent',
        'Topic :: Software Development'
    ],
    scripts = ["scripts/to_sentry",],
    url = "https://github.com/adamdeprince/to_sentry",
    install_requires = [
        'raven',
        ]
)

